How Tokens Work
===============
This article will explain the role that tokens play in the game engine, how 
tokens relate to the world, how a token extensions can be used to associate 
actor-specific data with tokens, and why non-read-only token methods can only 
be called at certain times.
